@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 
 from lintian_brush.fixer import control, report_result, LintianIssue
-from lintian_brush.rules import update_rules
+from debmutate._rules import update_rules
 
 
 def get_archs():
