@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 
-from debmutate.control import ControlEditor
 from lintian_brush.fixer import (
+    control,
     report_result,
     meets_minimum_certainty,
     fixed_lintian_tag,
@@ -14,7 +14,7 @@ CERTAINTY = "possible"
 if not meets_minimum_certainty(CERTAINTY):
     sys.exit(0)
 
-with ControlEditor() as updater:
+with control as updater:
     if "Rules-Requires-Root" not in updater.source:
         # TODO: add some heuristics to set require_root = "yes" in common
         # cases, like `debian/rules binary` chown(1)'ing stuff
