@@ -1,12 +1,11 @@
 #!/usr/bin/python3
 
-from debmutate.control import ControlEditor
 from email.utils import parseaddr
-from lintian_brush.fixer import report_result, fixed_lintian_tag
+from lintian_brush.fixer import control, report_result, fixed_lintian_tag
 
 QA_MAINTAINER = "Debian QA Group <packages@qa.debian.org>"
 
-with ControlEditor() as updater:
+with control as updater:
     try:
         email = parseaddr(updater.source["Maintainer"])[1]
     except KeyError:
