@@ -1,9 +1,8 @@
 #!/usr/bin/python3
-from debmutate.control import ControlEditor
-from lintian_brush.fixer import report_result, LintianIssue
+from lintian_brush.fixer import control, report_result, LintianIssue
 
 
-with ControlEditor() as updater:
+with control as updater:
     for key in list(updater.source):
         if not key.startswith('XS-Vcs-'):
             continue
