@@ -37,10 +37,9 @@ DEFAULT_BACKLOG = 50
 # what was in the commit messages?
 
 
-def gbp_conf_has_dch_section(tree: WorkingTree,
-                             path: str = '') -> Optional[bool]:
+def gbp_conf_has_dch_section(tree: WorkingTree, path: str = "") -> Optional[bool]:
     try:
-        gbp_conf_path = osutils.pathjoin(path, 'debian/gbp.conf')
+        gbp_conf_path = osutils.pathjoin(path, "debian/gbp.conf")
         gbp_conf_text = tree.get_file_text(gbp_conf_path)
     except NoSuchFile:
         return False
@@ -51,28 +50,27 @@ def gbp_conf_has_dch_section(tree: WorkingTree,
     else:
         parser = configparser.ConfigParser(defaults={}, strict=False)
         parser.read_string(
-            gbp_conf_text.decode('utf-8', errors='replace'), gbp_conf_path)
-        return parser.has_section('dch')
+            gbp_conf_text.decode("utf-8", errors="replace"), gbp_conf_path
+        )
+        return parser.has_section("dch")
 
 
 # TODO(jelmer): Use copy from debmutate.changelog
 def all_sha_prefixed(cl: Changelog) -> bool:
     sha_prefixed = 0
     for change in cl.changes():
-        if not change.startswith('  * '):
+        if not change.startswith("  * "):
             continue
-        if re.match(r'  \* \[[0-9a-f]{7}\] ', change):
+        if re.match(r"  \* \[[0-9a-f]{7}\] ", change):
             sha_prefixed += 1
         else:
             return False
-    return (sha_prefixed > 0)
+    return sha_prefixed > 0
 
 
 def guess_update_changelog(
-        tree: WorkingTree,
-        path: str = '',
-        cl: Optional[Changelog] = None
-        ) -> Optional[Tuple[bool, str]]:
+    tree: WorkingTree, path: str = "", cl: Optional[Changelog] = None
+) -> Optional[Tuple[bool, str]]:
     """Guess whether the changelog should be updated.
 
     Args:
@@ -91,16 +89,18 @@ def guess_update_changelog(
 
 
 def _guess_update_changelog_from_tree(
-        tree: Tree, path: str = '',
-        cl: Optional[Changelog] = None) -> Optional[Tuple[bool, str]]:
+    tree: Tree, path: str = "", cl: Optional[Changelog] = None
+) -> Optional[Tuple[bool, str]]:
     if gbp_conf_has_dch_section(tree, path):
         return (
-            False, 'Assuming changelog does not need to be updated, '
-            'since there is a [dch] section in gbp.conf.')
+            False,
+            "Assuming changelog does not need to be updated, "
+            "since there is a [dch] section in gbp.conf.",
+        )
 
     # TODO(jelmes): Do something more clever here, perhaps looking at history
     # of the changelog file?
-    changelog_path = osutils.pathjoin(path, 'debian/changelog')
+    changelog_path = osutils.pathjoin(path, "debian/changelog")
     if cl is None:
         try:
             with tree.get_file(changelog_path) as f:
@@ -111,15 +111,15 @@ def _guess_update_changelog_from_tree(
         if all_sha_prefixed(cl[0]):
             return (
                 False,
-                'Assuming changelog does not need to be updated, '
-                'since all entries in last changelog entry are prefixed '
-                'by git shas.')
+                "Assuming changelog does not need to be updated, "
+                "since all entries in last changelog entry are prefixed "
+                "by git shas.",
+            )
 
     return None
 
 
-def _greedy_revisions(
-        graph, revid: bytes, length: int) -> Tuple[List[bytes], bool]:
+def _greedy_revisions(graph, revid: bytes, length: int) -> Tuple[List[bytes], bool]:
     ret: List[bytes] = []
     it = graph.iter_lefthand_ancestry(revid)
     while len(ret) < length:
@@ -142,14 +142,13 @@ def _changelog_stats(branch: Branch, history: int, subpath: str):
     dch_references = 0
     with branch.lock_read():
         graph = branch.repository.get_graph()
-        revids, truncated = _greedy_revisions(
-            graph, branch.last_revision(), history)
+        revids, truncated = _greedy_revisions(graph, branch.last_revision(), history)
         revs = []
         for revid, rev in branch.repository.iter_revisions(revids):
             if rev is None:
                 # Ghost
                 continue
-            if 'Git-Dch: ' in rev.message:
+            if "Git-Dch: " in rev.message:
                 dch_references += 1
             revs.append(rev)
         try:
@@ -158,16 +157,21 @@ def _changelog_stats(branch: Branch, history: int, subpath: str):
             get_deltas = branch.repository.get_deltas_for_revisions
         for delta in get_deltas(revs):
             filenames = set(
-                [a.path[1] for a in delta.added] +
-                [r.path[0] for r in delta.removed] +
-                [r.path[0] for r in delta.renamed] +
-                [r.path[1] for r in delta.renamed] +
-                [m.path[0] for m in delta.modified])
-            if not set([
-                    f for f in filenames
-                    if f.startswith(osutils.pathjoin(subpath, 'debian/'))]):
+                [a.path[1] for a in delta.added]
+                + [r.path[0] for r in delta.removed]
+                + [r.path[0] for r in delta.renamed]
+                + [r.path[1] for r in delta.renamed]
+                + [m.path[0] for m in delta.modified]
+            )
+            if not set(
+                [
+                    f
+                    for f in filenames
+                    if f.startswith(osutils.pathjoin(subpath, "debian/"))
+                ]
+            ):
                 continue
-            if osutils.pathjoin(subpath, 'debian/changelog') in filenames:
+            if osutils.pathjoin(subpath, "debian/changelog") in filenames:
                 if len(filenames) > 1:
                     mixed += 1
                 else:
@@ -178,8 +182,8 @@ def _changelog_stats(branch: Branch, history: int, subpath: str):
 
 
 def _guess_update_changelog_from_branch(
-        branch: Branch, subpath: str = '',
-        history: int = DEFAULT_BACKLOG) -> Optional[Tuple[bool, str]]:
+    branch: Branch, subpath: str = "", history: int = DEFAULT_BACKLOG
+) -> Optional[Tuple[bool, str]]:
     """Guess whether the changelog should be updated manually.
 
     Args:
@@ -194,35 +198,41 @@ def _guess_update_changelog_from_branch(
     # - The vast majority of lines in changelog get added in
     #   commits that only touch the changelog
     (changelog_only, other_only, mixed, dch_references) = _changelog_stats(
-            branch, history, subpath)
+        branch, history, subpath
+    )
     if dch_references:
         return (
             False,
-            'Assuming changelog does not need to be updated, since '
-            'there are Gbp-Dch stanzas in commit messages')
+            "Assuming changelog does not need to be updated, since "
+            "there are Gbp-Dch stanzas in commit messages",
+        )
     if changelog_only == 0:
         return (
             True,
-            'Assuming changelog needs to be updated, since '
-            'it is always changed together with other files in the tree.')
+            "Assuming changelog needs to be updated, since "
+            "it is always changed together with other files in the tree.",
+        )
     if mixed == 0 and changelog_only > 0 and other_only > 0:
         # changelog is *always* updated in a separate commit.
         return (
             False,
-            'Assuming changelog does not need to be updated, since '
-            'changelog entries are always updated in separate commits.')
+            "Assuming changelog does not need to be updated, since "
+            "changelog entries are always updated in separate commits.",
+        )
     # Is this a reasonable threshold?
     if changelog_only > mixed and other_only > mixed:
         return (
             False,
-            'Assuming changelog does not need to be updated, since '
-            'changelog entries are usually updated in separate commits.')
+            "Assuming changelog does not need to be updated, since "
+            "changelog entries are usually updated in separate commits.",
+        )
     return None
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     import argparse
+
     parser = argparse.ArgumentParser()
     args = parser.parse_args()
-    wt, subpath = WorkingTree.open_containing('.')
+    wt, subpath = WorkingTree.open_containing(".")
     print(guess_update_changelog(wt, subpath))
