@@ -194,4 +194,13 @@ def source_package_name():
     return os.environ.get("PACKAGE")
 
 
+def vendor():
+    try:
+        return os.environ['DEB_VENDOR']
+    except KeyError:
+        with open('/etc/dpkg/origins/default', 'r') as f:
+            c = Deb822(f)
+            return c['Vendor']
+
+
 control = ControlEditor()
